b1td Usage — Bloxone API Wrapper 0.6.1 documentation

# b1td Usage

## Examples

Todo

These examples are placeholders, useful, but actual example set here is on the todo.

    bloxone.utils.reverse_labels("www.infoblox.com")

    import bloxone
    t = bloxone.b1td('/Users/marrison/configs/emea.ini')
    t.version
    bloxone.__version__
    t.tide_url
    t.threat_classes().json()
    t.threat_properties().json()
    t.threat_properties(threatclass="malwareC2").json()
    t.threat_properties(threatclass="malwareC2").json()
    t.dossierquery("eicar.co").json()
    t.expand_mitre_vector('DGA').json()
    t.threat_actor('APT1').json()